@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------#
-# Package: High-dimensional Undirected Graph Estimation (HUGE)          #
+# Package: High-dimensional Undirected pathraph Estimation (HUpathE)          #
 # huge(): Draw ROC Curve for a solution path                            #
 #         Must have a ground truth                                      #
 # Authors: Tuo Zhao and Han Liu                                         #
@@ -8,17 +8,8 @@
 # Version: 1.0                                                          #
 #-----------------------------------------------------------------------#
 
-huge.roc = function(est, theta, verbose = TRUE){
-	gcinfo(verbose = FALSE)
-	if(class(est) == "huge"){
-		G = est$path
-		if(is.null(est$theta)) cat("Error, true graph is not included!\n")
-		theta = est$theta
-	}
-	if(class(est) != "huge") G = est
-	rm(est)
-	gc()
-	
+huge.roc = function(path, theta, verbose = TRUE){
+	gcinfo(verbose = FALSE)	
 	ROC = list()
 	
 	theta = as.matrix(theta)
@@ -27,11 +18,11 @@ huge.roc = function(est, theta, verbose = TRUE){
 	neg.total = d*(d-1) - pos.total
 	
 	if(verbose) cat("Computing F1 scores, false positive rates and true positive rates....")
-	ROC$tp = rep(0,length(G))
-   	ROC$fp = rep(0,length(G))
-   	ROC$F1 = rep(0,length(G))
-   	for (r in 1:length(G)){
-   		tmp = as.matrix(G[[r]]) 
+	ROC$tp = rep(0,length(path))
+   	ROC$fp = rep(0,length(path))
+   	ROC$F1 = rep(0,length(path))
+   	for (r in 1:length(path)){
+   		tmp = as.matrix(path[[r]]) 
    		tp.all = (theta!=0)*(tmp!=0)
    		diag(tp.all) = 0
 		ROC$tp[r] <- sum(tp.all!=0)/pos.total
@@ -47,7 +38,7 @@ huge.roc = function(est, theta, verbose = TRUE){
 	}
 	if(verbose) cat("done.\n")
 		
-	rm(precision,recall,tp.all,fp.all,G,theta,fn)
+	rm(precision,recall,tp.all,fp.all,path,theta,fn)
    	gc()	
 		
 	ord.fp = order(ROC$fp)
